@@ -3,7 +3,8 @@
 #' Get summary results of historical stock size, recruitment, and fishing
 #' pressure.
 #'
-#' @param key the unique identifier of the stock assessment
+#' @param assessmentKey the unique identifier of the stock assessment
+#' @param ... to allow scope for back compatability
 #'
 #' @return A data frame.
 #'
@@ -19,27 +20,20 @@
 #' @author Colin Millar and Scott Large.
 #'
 #' @examples
-#' stocklist <- getListStocks(2016)
-#' id <- grep("cod-2224", stocklist$FishStockName)
-#' stocklist[id,]
-#' key <- stocklist$AssessmentKey[id]
-#' sumtab <- getSummaryTable(key)
+#' assessmentKey <- findAssessmentKey("cod-2224", year = 2016)
+#' sumtab <- getSummaryTable(assessmentKey)
 #' head(sumtab)
 #' attributes(sumtab)$notes
 #'
 #' @export
 
-getSummaryTable <- function(key) {
-  # check web services are running
-  if (!checkSAGWebserviceOK()) return (FALSE)
+getSummaryTable <- function(assessmentKey, ...) {
 
-  # read XML string and parse to data frame
-  url <-
-    sprintf(
-      "https://sg.ices.dk/StandardGraphsWebServices.asmx/getSummaryTable?key=%s",
-      key)
-  out <- readSAG(url)
-  out <- parseSummary(out)
+  assessmentKey <- checkKeyArg(assessmentKey = assessmentKey, ...)
 
-  out
+  # call webservice for all supplied keys
+  out <- lapply(assessmentKey, function(i) sag_webservice("getSummaryTable", assessmentKey = i))
+
+  # parse output
+  lapply(out, sag_parse, type = "summary")
 }
